#
# spec file for package libunistring
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover	5
Name:           libunistring
Version:        1.3
Release:        1.3
Summary:        GNU Unicode string library
License:        GPL-3.0-or-later OR LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gnu.org/software/libunistring/
Source0:        http://ftp.gnu.org/gnu/libunistring/libunistring-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/libunistring/libunistring-%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/people/viewgpg.php?user_id=1871/%{name}.keyring
Source3:        baselibs.conf

%description
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).

%package devel
Summary:        Development files for the GNU Unicode string library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
Development files for programs using libunistring and documentation
for UniString library.

%package -n %{name}%{sover}
Summary:        GNU Unicode string library
Group:          System/Libraries

%description -n %{name}%{sover}
This portable C library implements Unicode string types in three flavours:
(UTF-8, UTF-16, UTF-32), together with functions for character processing
(names, classifications, properties) and functions for string processing
(iteration, formatted output, width, word breaks, line breaks, normalization,
case folding and regular expressions).

%prep
%autosetup -p1

%build
%configure --disable-static --disable-rpath --docdir=%{_docdir}/%{name}
%make_build

%install
%make_install
cp AUTHORS NEWS README HACKING DEPENDENCIES THANKS ChangeLog %{buildroot}/%{_docdir}/%{name}
rm -f %{buildroot}/%{_infodir}/dir
rm -f %{buildroot}/%{_libdir}/libunistring.la

%check
# test-malloca seem not to be suitable for ix86 obs worker
# (locally passes, obs worker stucks -- )
%ifarch %{ix86}
sed -i 's:50000:50:g' tests/test-malloca.c
%endif
# do not run tests in parallel, it stucks randomly
%make_build check #

%ldconfig_scriptlets -n %{name}%{sover}

%files -n %{name}%{sover}
%license COPYING*
%{_libdir}/libunistring.so.%{sover}{,.*}

%files devel
%license COPYING*
%{_docdir}/%{name}
%{_infodir}/libunistring.info%{?ext_info}
%{_libdir}/libunistring.so
%{_includedir}/unistring
%{_includedir}/*.h

%changelog
* Thu Oct 17 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.3:
  * Support Unicode version 16.0.0
* Sat Feb 24 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.2:
  * Support Unicode 15.1.0
  * Improve UTF-8 decoder Unicode Standard compliance
  * The *printf functions no longer support the %%n directive, for
    security reasons.
  * Fixed a bug in the *printf functions: In the %%U, %%lU, %%llU
    directives, a negative width given as an argument did not
    trigger left-justification.
  * The functions u16_strstr and u32_strstr now operate in worst-case linear time.
  * Useful API function extensions
* Mon Aug 28 2023 Andreas Schwab <schwab@suse.de>
- Run testsuite also under qemu emulation
* Thu Apr 20 2023 Frederic Crozat <fcrozat@suse.com>
- Fix license tag to GPL-3.0-or-later or LGPL-3.0-or-later.
* Tue Oct 25 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.1:
  * The data tables and algorithms have been updated to Unicode
    version 15.0.0.
* Sat Apr  9 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.0:
  * Unicode 14.0.0 support
  * License changed to LGPL-3.0-or-later OR GPL-2.0-or-later
  * *_uctomb functions now support strings larger than 2 GiB
  * linebreak functions now make it easier to work with strings
    that contain CR-LF sequences
  * New properties for recognizing pictographics symbols and
    regional indicators
- drop disable-broken-tests.patch
* Fri Mar  8 2019 Martin Liška <mliska@suse.cz>
- Add disable-broken-tests.patch in order to fix broken
  tests (bnc#1128460).
* Mon May 28 2018 astieger@suse.com
- update to 0.9.10:
  * The functions
    u8_casing_prefix_context, u8_casing_prefixes_context,
    u8_casing_suffix_context, u8_casing_suffixes_context,
    u16_casing_prefix_context, u16_casing_prefixes_context,
    u16_casing_suffix_context, u16_casing_suffixes_context,
    u32_casing_prefix_context, u32_casing_prefixes_context,
    u32_casing_suffix_context, u32_casing_suffixes_context,
    that are documented since version 0.9.1, are now actually
    implemented.
* Sat Mar  3 2018 jengelh@inai.de
- Fix RPM groups and summaries.
* Wed Feb 28 2018 astieger@suse.com
- update to 0.9.9:
  * Fixed a multithread-safety bug
* Fri Dec  1 2017 astieger@suse.com
- update to 0.9.8:
  * The data tables and line breaking algorithm have been updated
    to Unicode version 9.0.0
  * In the include file unigbrk.h, the function uc_grapheme_breaks
    has been added to accommodate the new UAX#29 rules involving 3
    or more consecutive characters
* Fri Aug 18 2017 pgajdos@suse.com
- try to not run tests in parallel, make check stucks randomly
* Fri May  5 2017 pgajdos@suse.com
- updated to 0.9.7:
  * license change
  * build system changes
* Tue Jan  3 2017 mlin@suse.com
- Add baselibs.conf to generate -32bit packages
* Thu Jul  9 2015 astieger@suse.com
- GNU libunistring 0.9.6:
  * The data tables and line breaking algorithm have been updated
    to Unicode version 8.0.0.
- add keyring and verify source signature
- fix SLE 11 SP3 build
* Thu Feb 19 2015 p.drouand@gmail.com
- Update to version 0.9.5
  * The data tables and line breaking algorithm have been updated
    to Unicode version 7.0.0.
  * In the include file uniname.h, the function unicode_name_character
    has been extended to look for name aliases.
- Remove patches merged on upstream release
  * libunistring-gnulib-ppc64le.patch
  * libunistring-parallel-make.patch
- Use download Url as source
- Remove autoconf, automake and libtool require; not needed anymore
- Bump so version to 2
  libunistring0 > libunistring2
* Tue Mar  4 2014 pgajdos@suse.com
- fix parallel build
  * added parallel-make.patch [bnc#866723] (private)
* Wed Dec 18 2013 uweigand@de.ibm.com
- libunistring-gnulib-ppc64le.patch: Fix imported gnulib long double
  math tests for little-endian PowerPC.
* Fri Mar 16 2012 cfarrell@suse.com
- license update: LGPL-3.0+ and GPL-3.0+
  Numerous files in tests/ and woedll are GPL-3.0+ licensed. Either put
  them in a separate GPL-3.0+ labelled subpackage or use this label for the
  main License: line
* Sun Mar 11 2012 jengelh@medozas.de
- Nuke unnecessary libunistring binary package: move documentation
  files to devel subpackage
* Mon Jan 30 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Fri Sep 30 2011 crrodriguez@opensuse.org
- Workaround qemu-arm bugs.
* Mon Aug 30 2010 pgajdos@suse.cz
- updated to version 0.9.3:
  * Bug fixes in unistr.h functions:
  - The functions u16_to_u32, u16_to_u8, u8_to_u32, u8_to_u16 now fail when
    the argument is not valid. Previously, they returned a converted string
    where invalid parts were each replaced with U+FFFD.
  - The function u8_mbsnlen now counts an incomplete character at the end
    of the argument string as 1 character. Previously, it could count as 2
    or 3 characters.
  - The return value of the u8_stpncpy, u16_stpncpy, u32_stpncpy functions
    was incorrect.
  - The u8_strcoll, u16_strcoll, u32_strcoll now try harder to give a non-zero
    return value.
* Mon Mar 15 2010 pgajdos@suse.cz
- updated to version 0.9.2.1:
  * The function uc_locale_language now uses the locale of the
    current thread, if a thread-specific locale has been set.
* Tue Nov 24 2009 pgajdos@suse.cz
- initial version of package 0.9.1.1
- spec file taken from
  http://www.pixelbeat.org/patches/libunistring
  (PĂĄdraig Brady <P@draigBrady.com)
- needed by guile 1.9.0 and higher
